@@ -1,21 +1,44 @@
 package operations
 
 import (
+	"bufio"
 	"context"
+	"errors"
+	"fmt"
 	"io"
 
-	"github.com/pkg/errors"
 	"github.com/rclone/rclone/fs"
 	"github.com/rclone/rclone/fs/accounting"
 	"golang.org/x/sync/errgroup"
 )
 
 const (
-	multithreadChunkSize     = 64 << 10
-	multithreadChunkSizeMask = multithreadChunkSize - 1
-	multithreadBufferSize    = 32 * 1024
+	multithreadChunkSize      = 64 << 10
+	multithreadChunkSizeMask  = multithreadChunkSize - 1
+	multithreadReadBufferSize = 32 * 1024
 )
 
+// An offsetWriter maps writes at offset base to offset base+off in the underlying writer.
+//
+// Modified from the go source code. Can be replaced with
+// io.OffsetWriter when we no longer need to support go1.19
+type offsetWriter struct {
+	w   io.WriterAt
+	off int64 // the current offset
+}
+
+// newOffsetWriter returns an offsetWriter that writes to w
+// starting at offset off.
+func newOffsetWriter(w io.WriterAt, off int64) *offsetWriter {
+	return &offsetWriter{w, off}
+}
+
+func (o *offsetWriter) Write(p []byte) (n int, err error) {
+	n, err = o.w.WriteAt(p, o.off)
+	o.off += int64(n)
+	return
+}
+
 // Return a boolean as to whether we should use multi thread copy for
 // this transfer
 func doMultiThreadCopy(ctx context.Context, f fs.Fs, src fs.Object) bool {
@@ -27,11 +50,15 @@ func doMultiThreadCopy(ctx context.Context, f fs.Fs, src fs.Object) bool {
 	if ci.MultiThreadStreams <= 1 {
 		return false
 	}
+	// ...if the source doesn't support it
+	if src.Fs().Features().NoMultiThreading {
+		return false
+	}
 	// ...size of object is less than cutoff
 	if src.Size() < int64(ci.MultiThreadCutoff) {
 		return false
 	}
-	// ...source doesn't support it
+	// ...destination doesn't support it
 	dstFeatures := f.Features()
 	if dstFeatures.OpenWriterAt == nil {
 		return false
@@ -74,14 +101,19 @@ func (mc *multiThreadCopyState) copyStream(ctx context.Context, stream int) (err
 
 	fs.Debugf(mc.src, "multi-thread copy: stream %d/%d (%d-%d) size %v starting", stream+1, mc.streams, start, end, fs.SizeSuffix(end-start))
 
-	rc, err := NewReOpen(ctx, mc.src, ci.LowLevelRetries, &fs.RangeOption{Start: start, End: end - 1})
+	rc, err := Open(ctx, mc.src, &fs.RangeOption{Start: start, End: end - 1})
 	if err != nil {
-		return errors.Wrap(err, "multipart copy: failed to open source")
+		return fmt.Errorf("multipart copy: failed to open source: %w", err)
 	}
 	defer fs.CheckClose(rc, &err)
 
+	var writer io.Writer = newOffsetWriter(mc.wc, start)
+	if ci.MultiThreadWriteBufferSize > 0 {
+		writer = bufio.NewWriterSize(writer, int(ci.MultiThreadWriteBufferSize))
+		fs.Debugf(mc.src, "multi-thread copy: write buffer set to %v", ci.MultiThreadWriteBufferSize)
+	}
 	// Copy the data
-	buf := make([]byte, multithreadBufferSize)
+	buf := make([]byte, multithreadReadBufferSize)
 	offset := start
 	for {
 		// Check if context cancelled and exit if so
@@ -92,29 +124,39 @@ func (mc *multiThreadCopyState) copyStream(ctx context.Context, stream int) (err
 		if nr > 0 {
 			err = mc.acc.AccountRead(nr)
 			if err != nil {
-				return errors.Wrap(err, "multipart copy: accounting failed")
+				return fmt.Errorf("multipart copy: accounting failed: %w", err)
 			}
-			nw, ew := mc.wc.WriteAt(buf[0:nr], offset)
+			nw, ew := writer.Write(buf[0:nr])
 			if nw > 0 {
 				offset += int64(nw)
 			}
 			if ew != nil {
-				return errors.Wrap(ew, "multipart copy: write failed")
+				return fmt.Errorf("multipart copy: write failed: %w", ew)
 			}
 			if nr != nw {
-				return errors.Wrap(io.ErrShortWrite, "multipart copy")
+				return fmt.Errorf("multipart copy: %w", io.ErrShortWrite)
 			}
 		}
 		if er != nil {
 			if er != io.EOF {
-				return errors.Wrap(er, "multipart copy: read failed")
+				return fmt.Errorf("multipart copy: read failed: %w", er)
 			}
+
+			// if we were buffering, flush do disk
+			switch w := writer.(type) {
+			case *bufio.Writer:
+				er2 := w.Flush()
+				if er2 != nil {
+					return fmt.Errorf("multipart copy: flush failed: %w", er2)
+				}
+			}
+
 			break
 		}
 	}
 
 	if offset != end {
-		return errors.Errorf("multipart copy: wrote %d bytes but expected to write %d", offset-start, end-start)
+		return fmt.Errorf("multipart copy: wrote %d bytes but expected to write %d", offset-start, end-start)
 	}
 
 	fs.Debugf(mc.src, "multi-thread copy: stream %d/%d (%d-%d) size %v finished", stream+1, mc.streams, start, end, fs.SizeSuffix(end-start))
@@ -166,7 +208,7 @@ func multiThreadCopy(ctx context.Context, f fs.Fs, remote string, src fs.Object,
 	// create write file handle
 	mc.wc, err = openWriterAt(gCtx, remote, mc.size)
 	if err != nil {
-		return nil, errors.Wrap(err, "multipart copy: failed to open destination")
+		return nil, fmt.Errorf("multipart copy: failed to open destination: %w", err)
 	}
 
 	fs.Debugf(src, "Starting multi-thread copy with %d parts of size %v", mc.streams, fs.SizeSuffix(mc.partSize))
@@ -182,19 +224,19 @@ func multiThreadCopy(ctx context.Context, f fs.Fs, remote string, src fs.Object,
 		return nil, err
 	}
 	if closeErr != nil {
-		return nil, errors.Wrap(closeErr, "multi-thread copy: failed to close object after copy")
+		return nil, fmt.Errorf("multi-thread copy: failed to close object after copy: %w", closeErr)
 	}
 
 	obj, err := f.NewObject(ctx, remote)
 	if err != nil {
-		return nil, errors.Wrap(err, "multi-thread copy: failed to find object after copy")
+		return nil, fmt.Errorf("multi-thread copy: failed to find object after copy: %w", err)
 	}
 
 	err = obj.SetModTime(ctx, src.ModTime(ctx))
 	switch err {
 	case nil, fs.ErrorCantSetModTime, fs.ErrorCantSetModTimeWithoutDelete:
 	default:
-		return nil, errors.Wrap(err, "multi-thread copy: failed to set modification time")
+		return nil, fmt.Errorf("multi-thread copy: failed to set modification time: %w", err)
 	}
 
 	fs.Debugf(src, "Finished multi-thread copy with %d parts of size %v", mc.streams, fs.SizeSuffix(mc.partSize))
