@@ -5,11 +5,11 @@ import (
 	"path/filepath"
 )
 
-// OsFindParent returns the parent directory of name, or "" for the
+// OSFindParent returns the parent directory of name, or "" for the
 // root for OS native paths.
-func OsFindParent(name string) string {
+func OSFindParent(name string) string {
 	parent := filepath.Dir(name)
-	if parent == "." || parent == "/" {
+	if parent == "." || (len(parent) == 1 && parent[0] == filepath.Separator) {
 		parent = ""
 	}
 	return parent
